@@ -21,7 +21,7 @@ private:
         QPoint discposition;
 
 protected:
-    void paintEvent(QPaintEvent *event);
+    void paintEvent();
     void mouseMoveEvent(QMouseEvent *event);
     //void mousePressEvent(QMouseEvent *event);
 
